class Arguments(object):
    def __init__(self, number=None, dexdate=None, apksize=None, vtdetection=None, markets=None, pkgname=None, metadata=None, sha256=None, sha1=None, md5=None, key=None, input_file=None):
        self.number = number
        self.dexdate = dexdate
        self.apksize = apksize
        self.vtdetection = vtdetection
        self.markets = markets
        self.pkgname = pkgname
        self.metadata = metadata
        self.sha256 = sha256
        self.sha1 = sha1
        self.md5 = md5
        self.key = key
        self.input_file = input_file
